/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* 
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is the Netscape Portable Runtime (NSPR).
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are 
 * Copyright (C) 1998-2000 Netscape Communications Corporation.  All
 * Rights Reserved.
 * 
 * Contributor(s):
 * 
 * Alternatively, the contents of this file may be used under the
 * terms of the GNU General Public License Version 2 or later (the
 * "GPL"), in which case the provisions of the GPL are applicable 
 * instead of those above.  If you wish to allow use of your 
 * version of this file only under the terms of the GPL and not to
 * allow others to use your version of this file under the MPL,
 * indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by
 * the GPL.  If you do not delete the provisions above, a recipient
 * may use your version of this file under either the MPL or the
 * GPL.
 */

/*
** Class: RCMonitor (ref prmonitor.h)
**
** RCMonitor.h - C++ wrapper around NSPR's monitors
*/
#if defined(_RCMONITOR_H)
#else
#define _RCMONITOR_H

#include "rcbase.h"
#include "rcinrval.h"

struct PRMonitor;

class PR_IMPLEMENT(RCMonitor): public RCBase
{
public:
    RCMonitor();                    /* timeout is infinity */
    virtual ~RCMonitor();

    virtual void Enter();           /* reentrant entry */
    virtual void Exit();

    virtual void Notify();          /* possibly enable one thread */
    virtual void NotifyAll();       /* enable all waiters */

    virtual void Wait();            /* applies object's timeout */

    virtual void SetTimeout(const RCInterval& timeout);

private:
    PRMonitor *monitor;
    RCInterval timeout;

public:
    RCInterval GetTimeout() const;  /* get the current value */

};  /* RCMonitor */

#endif /* defined(_RCMONITOR_H) */

/* RCMonitor.h */
